ConsentState

Enum ConsentState 

#[non_exhaustive]
pub enum ConsentState { Granted, Denied, Withdrawn, NotCollected, }
The current state of consent for a given purpose.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Granted

Consent has been explicitly granted.



Denied

Consent has been explicitly denied.



Withdrawn

Consent was previously granted but has been withdrawn.



NotCollected

Consent has not yet been collected for this purpose.